@@ -145,7 +145,7 @@ Plugin.create :extract do
 
   defextractcondition(:user, name: _('ユーザ名'), operator: true, args: 1, sexp: MIKU.parse("`(,compare (idname (user message)) ,(car args))"))
 
-  defextractcondition(:body, name: _('本文'), operator: true, args: 1, sexp: MIKU.parse("`(,compare (to_s message) ,(car args))"))
+  defextractcondition(:body, name: _('本文'), operator: true, args: 1, sexp: MIKU.parse("`(,compare (description message) ,(car args))"))
 
   defextractcondition(:source, name: _('Twitterクライアント'), operator: true, args: 1, sexp: MIKU.parse("`(,compare (fetch message 'source) ,(car args))"))
 
@@ -181,9 +181,7 @@ Plugin.create :extract do
     extract_tabs[setting.slug] = setting
     tab(setting.slug).set_icon setting.icon.to_s if setting.icon?
     oo = setting.find_ordering_obj
-    if oo
-      timeline(setting.slug).order(&setting.find_ordering_obj.ordering)
-    end
+    timeline(setting.slug).order(&oo.ordering) if oo
     modify_extract_tabs end
 
   on_extract_tab_delete do |slug|
